@@ -5,8 +5,6 @@
  * See top-level LICENSE file for more information
  */
 
-const vaultItems = [];
-
 const progressbarColors = {
   'new': 'rgba(128, 128, 128, 0.5)',
   'pending': 'rgba(0, 0, 255, 0.5)',
@@ -23,24 +21,23 @@ function checkVaultCookingTask(objectType) {
   cy.wait('@checkVaultCookingTask');
 }
 
-function updateVaultItemList(vaultUrl, vaultItems) {
-  cy.visit(vaultUrl)
-    .then(() => {
-      // Add uncooked task to localStorage
-      // which updates it in vault items list
-      window.localStorage.setItem('swh-vault-cooking-tasks', JSON.stringify(vaultItems));
-    });
+function getVaultItemList() {
+  return JSON.parse(window.localStorage.getItem('swh-vault-cooking-tasks'));
 }
 
-// Mocks API response : /api/1/vault/(:objectType)/(:hash)
-// objectType : {'directory', 'revision'}
-function genVaultCookingResponse(objectType, objectId, status, message, fetchUrl) {
+function updateVaultItemList(vaultItems) {
+  window.localStorage.setItem('swh-vault-cooking-tasks', JSON.stringify(vaultItems));
+}
+
+// Mocks API response : /api/1/vault/(:bundleType)/(:swhid)
+// bundleType : {'flat', 'git_bare'}
+function genVaultCookingResponse(bundleType, swhid, status, message, fetchUrl) {
   return {
-    'obj_type': objectType,
+    'bundle_type': bundleType,
     'id': 1,
     'progress_message': message,
     'status': status,
-    'obj_id': objectId,
+    'swhid': swhid,
     'fetch_url': fetchUrl
   };
 };
@@ -48,7 +45,7 @@ function genVaultCookingResponse(objectType, objectId, status, message, fetchUrl
 // Tests progressbar color, status
 // And status in localStorage
 function testStatus(taskId, color, statusMsg, status) {
-  cy.get(`.swh-vault-table #vault-task-${taskId}`)
+  cy.get(`.swh-vault-table #vault-task-${CSS.escape(taskId)}`)
     .should('be.visible')
     .find('.progress-bar')
     .should('be.visible')
@@ -56,8 +53,8 @@ function testStatus(taskId, color, statusMsg, status) {
     .and('contain', statusMsg)
     .then(() => {
       // Vault item with object_id as taskId should exist in localStorage
-      const currentVaultItems = JSON.parse(window.localStorage.getItem('swh-vault-cooking-tasks'));
-      const vaultItem = currentVaultItems.find(obj => obj.object_id === taskId);
+      const currentVaultItems = getVaultItemList();
+      const vaultItem = currentVaultItems.find(obj => obj.swhid === taskId);
 
       assert.isNotNull(vaultItem);
       assert.strictEqual(vaultItem.status, status);
@@ -68,39 +65,54 @@ describe('Vault Cooking User Interface Tests', function() {
 
   before(function() {
     const dirInfo = this.origin[0].directory[0];
-    this.directory = dirInfo.id;
+    this.directory = `swh:1:dir:${dirInfo.id}`;
     this.directoryUrl = this.Urls.browse_origin_directory() +
       `?origin_url=${this.origin[0].url}&path=${dirInfo.path}`;
-    this.vaultDirectoryUrl = this.Urls.api_1_vault_cook_directory(this.directory);
-    this.vaultFetchDirectoryUrl = this.Urls.api_1_vault_fetch_directory(this.directory);
+    this.vaultDirectoryUrl = this.Urls.api_1_vault_cook_flat(this.directory);
+    this.vaultFetchDirectoryUrl = this.Urls.api_1_vault_fetch_flat(this.directory);
 
-    this.revision = this.origin[1].revisions[0];
-    this.revisionUrl = this.Urls.browse_revision(this.revision);
-    this.vaultRevisionUrl = this.Urls.api_1_vault_cook_revision_gitfast(this.revision);
-    this.vaultFetchRevisionUrl = this.Urls.api_1_vault_fetch_revision_gitfast(this.revision);
+    this.revisionId = this.origin[1].revisions[0];
+    this.revision = `swh:1:rev:${this.revisionId}`;
+    this.revisionUrl = this.Urls.browse_revision(this.revisionId);
+    this.vaultRevisionUrl = this.Urls.api_1_vault_cook_git_bare(this.revision);
+    this.vaultFetchRevisionUrl = this.Urls.api_1_vault_fetch_git_bare(this.revision);
 
     const release = this.origin[1].release;
     this.releaseUrl = this.Urls.browse_release(release.id) + `?origin_url=${this.origin[1].url}`;
-    this.vaultReleaseDirectoryUrl = this.Urls.api_1_vault_cook_directory(release.directory);
-
-    vaultItems[0] = {
-      'object_type': 'revision',
-      'object_id': this.revision,
-      'email': '',
-      'status': 'done',
-      'fetch_url': `/api/1/vault/revision/${this.revision}/gitfast/raw/`,
-      'progress_message': null
-    };
+    this.vaultReleaseDirectoryUrl = this.Urls.api_1_vault_cook_flat(`swh:1:dir:${release.directory}`);
   });
 
   beforeEach(function() {
+    // For some reason, this gets reset if we define it in the before() hook,
+    // so we need to define it here
+    this.vaultItems = [
+      {
+        'bundle_type': 'git_bare',
+        'swhid': this.revision,
+        'email': '',
+        'status': 'done',
+        'fetch_url': `/api/1/vault/git-bare/${this.revision}/raw/`,
+        'progress_message': null
+      }
+    ];
+    this.legacyVaultItems = [
+      {
+        'object_type': 'revision',
+        'object_id': this.revisionId,
+        'email': '',
+        'status': 'done',
+        'fetch_url': `/api/1/vault/revision/${this.revisionId}/gitfast/raw/`,
+        'progress_message': null
+      }
+    ];
+
     this.genVaultDirCookingResponse = (status, message = null) => {
-      return genVaultCookingResponse('directory', this.directory, status,
+      return genVaultCookingResponse('flat', this.directory, status,
                                      message, this.vaultFetchDirectoryUrl);
     };
 
     this.genVaultRevCookingResponse = (status, message = null) => {
-      return genVaultCookingResponse('revision', this.revision, status,
+      return genVaultCookingResponse('git_bare', this.revision, status,
                                      message, this.vaultFetchRevisionUrl);
     };
 
@@ -158,6 +170,29 @@ describe('Vault Cooking User Interface Tests', function() {
       .should('contain', 'Archive cooking request submission failed.');
   });
 
+  it('should display previous cooking tasks', function() {
+
+    updateVaultItemList(this.vaultItems);
+
+    cy.visit(this.Urls.browse_vault());
+
+    cy.contains(`#vault-task-${CSS.escape(this.revision)} button`, 'Download')
+      .click();
+  });
+
+  it('should display and upgrade previous cooking tasks from the legacy format', function() {
+    updateVaultItemList(this.legacyVaultItems);
+
+    cy.visit(this.Urls.browse_vault());
+
+    // Check it is displayed
+    cy.contains(`#vault-task-${CSS.escape(this.revision)} button`, 'Download')
+      .then(() => {
+        // Check the LocalStorage was upgraded
+        expect(getVaultItemList()).to.deep.equal(this.vaultItems);
+      });
+  });
+
   it('should create a directory cooking task and report the success', function() {
 
     // Browse a directory
@@ -165,9 +200,9 @@ describe('Vault Cooking User Interface Tests', function() {
 
     // Stub response to the vault API to simulate archive download
     cy.intercept('GET', this.vaultFetchDirectoryUrl, {
-      fixture: `${this.directory}.tar.gz`,
+      fixture: `${this.directory.replace(/:/g, '_')}.tar.gz`,
       headers: {
-        'Content-disposition': `attachment; filename=${this.directory}.tar.gz`,
+        'Content-disposition': `attachment; filename=${this.directory.replace(/:/g, '_')}.tar.gz`,
         'Content-Type': 'application/gzip'
       }
     }).as('fetchCookedArchive');
@@ -225,15 +260,19 @@ describe('Vault Cooking User Interface Tests', function() {
         testStatus(this.directory, progressbarColors['done'], 'done', 'done');
       });
 
-      cy.get(`#vault-task-${this.directory} .vault-origin a`)
+      cy.get(`#vault-task-${CSS.escape(this.directory)} .vault-origin a`)
         .should('contain', this.origin[0].url)
         .should('have.attr', 'href', `${this.Urls.browse_origin()}?origin_url=${this.origin[0].url}`);
 
-      cy.get(`#vault-task-${this.directory} .vault-object-info a`)
+      cy.get(`#vault-task-${CSS.escape(this.directory)} .vault-object-info a`)
         .should('have.text', this.directory)
         .should('have.attr', 'href', browseDirectoryUrl);
 
-      cy.get(`#vault-task-${this.directory} .vault-dl-link button`)
+      cy.get(`#vault-task-${CSS.escape(this.directory)}`)
+        .invoke('attr', 'title')
+        .should('contain', 'the directory can be extracted');
+
+      cy.get(`#vault-task-${CSS.escape(this.directory)} .vault-dl-link button`)
         .click();
 
       cy.wait('@fetchCookedArchive').then((xhr) => {
@@ -250,10 +289,10 @@ describe('Vault Cooking User Interface Tests', function() {
 
     // Stub response to the vault API indicating to simulate archive download
     cy.intercept({url: this.vaultFetchRevisionUrl}, {
-      fixture: `${this.revision}.gitfast.gz`,
+      fixture: `${this.revision.replace(/:/g, '_')}.git.tar`,
       headers: {
-        'Content-disposition': `attachment; filename=${this.revision}.gitfast.gz`,
-        'Content-Type': 'application/gzip'
+        'Content-disposition': `attachment; filename=${this.revision.replace(/:/g, '_')}.git.tar`,
+        'Content-Type': 'application/x-tar'
       }
     }).as('fetchCookedArchive');
 
@@ -310,14 +349,18 @@ describe('Vault Cooking User Interface Tests', function() {
         testStatus(this.revision, progressbarColors['done'], 'done', 'done');
       });
 
-      cy.get(`#vault-task-${this.revision} .vault-origin`)
+      cy.get(`#vault-task-${CSS.escape(this.revision)} .vault-origin`)
         .should('have.text', 'unknown');
 
-      cy.get(`#vault-task-${this.revision} .vault-object-info a`)
+      cy.get(`#vault-task-${CSS.escape(this.revision)} .vault-object-info a`)
         .should('have.text', this.revision)
         .should('have.attr', 'href', browseRevisionUrl);
 
-      cy.get(`#vault-task-${this.revision} .vault-dl-link button`)
+      cy.get(`#vault-task-${CSS.escape(this.revision)}`)
+        .invoke('attr', 'title')
+        .should('contain', 'the git repository can be imported');
+
+      cy.get(`#vault-task-${CSS.escape(this.revision)} .vault-dl-link button`)
         .click();
 
       cy.wait('@fetchCookedArchive').then((xhr) => {
@@ -364,9 +407,9 @@ describe('Vault Cooking User Interface Tests', function() {
         .should('contain', 'Archive cooking request successfully submitted.');
   });
 
-  it('should offer to recook an archive if no more available to download', function() {
+  it('should offer to recook an archive if no longer available for download', function() {
 
-    updateVaultItemList(this.Urls.browse_vault(), vaultItems);
+    updateVaultItemList(this.vaultItems);
 
     // Send 404 when fetching vault item
     cy.intercept({url: this.vaultFetchRevisionUrl}, {
@@ -380,7 +423,8 @@ describe('Vault Cooking User Interface Tests', function() {
       }
     }).as('fetchCookedArchive');
 
-    cy.get(`#vault-task-${this.revision} .vault-dl-link button`)
+    cy.visit(this.Urls.browse_vault())
+      .get(`#vault-task-${CSS.escape(this.revision)} .vault-dl-link button`)
       .click();
 
     cy.wait('@fetchCookedArchive').then(() => {
@@ -406,15 +450,16 @@ describe('Vault Cooking User Interface Tests', function() {
 
   it('should remove selected vault items', function() {
 
-    updateVaultItemList(this.Urls.browse_vault(), vaultItems);
+    updateVaultItemList(this.vaultItems);
 
-    cy.get(`#vault-task-${this.revision}`)
+    cy.visit(this.Urls.browse_vault())
+      .get(`#vault-task-${CSS.escape(this.revision)}`)
       .find('input[type="checkbox"]')
       .click({force: true});
     cy.contains('button', 'Remove selected tasks')
       .click();
 
-    cy.get(`#vault-task-${this.revision}`)
+    cy.get(`#vault-task-${CSS.escape(this.revision)}`)
       .should('not.exist');
   });
 
@@ -425,9 +470,9 @@ describe('Vault Cooking User Interface Tests', function() {
 
     // Stub response to the vault API to simulate archive download
     cy.intercept({url: this.vaultFetchDirectoryUrl}, {
-      fixture: `${this.directory}.tar.gz`,
+      fixture: `${this.directory.replace(/:/g, '_')}.tar.gz`,
       headers: {
-        'Content-disposition': `attachment; filename=${this.directory}.tar.gz`,
+        'Content-disposition': `attachment; filename=${this.directory.replace(/:/g, '_')}.tar.gz`,
         'Content-Type': 'application/gzip'
       }
     }).as('fetchCookedArchive');
@@ -451,17 +496,17 @@ describe('Vault Cooking User Interface Tests', function() {
 
   });
 
-  it('should offer to immediately download a revision gitfast archive if already cooked', function() {
+  it('should offer to immediately download a bare revision git archive if already cooked', function() {
     cy.adminLogin();
     // Browse a directory
     cy.visit(this.revisionUrl);
 
     // Stub response to the vault API to simulate archive download
     cy.intercept({url: this.vaultFetchRevisionUrl}, {
-      fixture: `${this.revision}.gitfast.gz`,
+      fixture: `${this.revision.replace(/:/g, '_')}.git.tar`,
       headers: {
-        'Content-disposition': `attachment; filename=${this.revision}.gitfast.gz`,
-        'Content-Type': 'application/gzip'
+        'Content-disposition': `attachment; filename=${this.revision.replace(/:/g, '_')}.git.tar`,
+        'Content-Type': 'application/x-tar'
       }
     }).as('fetchCookedArchive');
 
