@@ -10,7 +10,6 @@ from typing import Any, Dict, List, Optional, Tuple
 
 from django.core.cache import cache
 from django.shortcuts import render
-from django.template.defaultfilters import filesizeformat
 from django.utils.html import escape
 
 from swh.model.hashutil import hash_to_bytes
@@ -85,6 +84,9 @@ def _get_branch(branches, branch_name, snapshot_id):
             branches_from=branch_name,
             branches_count=1,
             target_types=["revision", "alias"],
+            # pull request branches must be browsable even if they are hidden
+            # by default in branches list
+            branch_name_exclude_prefix=None,
         )
         snp_branch, _, _ = process_snapshot_branches(snp)
         if snp_branch and snp_branch[0]["name"] == branch_name:
@@ -769,7 +771,6 @@ def browse_snapshot_directory(
         )
         if f["length"] is not None:
             sum_file_sizes += f["length"]
-            f["length"] = filesizeformat(f["length"])
         if f["name"].lower().startswith("readme"):
             readmes[f["name"]] = f["checksums"]["sha1"]
 
@@ -793,9 +794,10 @@ def browse_snapshot_directory(
     if root_directory:
         nb_files = len(files)
         nb_dirs = len(dirs)
-        sum_file_sizes = filesizeformat(sum_file_sizes)
         dir_path = "/" + path
 
+    swh_objects = []
+    vault_cooking = {}
     revision_found = True
     if sha1_git is None and revision_id is not None:
         try:
@@ -803,11 +805,17 @@ def browse_snapshot_directory(
         except NotFoundExc:
             revision_found = False
 
-    swh_objects = [
-        SWHObjectInfo(object_type=DIRECTORY, object_id=sha1_git),
-        SWHObjectInfo(object_type=REVISION, object_id=revision_id),
-        SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id),
-    ]
+    if sha1_git is not None:
+        swh_objects.append(SWHObjectInfo(object_type=DIRECTORY, object_id=sha1_git))
+        vault_cooking.update(
+            {"directory_context": True, "directory_swhid": f"swh:1:dir:{sha1_git}",}
+        )
+    if revision_found:
+        swh_objects.append(SWHObjectInfo(object_type=REVISION, object_id=revision_id))
+        vault_cooking.update(
+            {"revision_context": True, "revision_swhid": f"swh:1:rev:{revision_id}",}
+        )
+    swh_objects.append(SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id))
 
     visit_date = None
     visit_type = None
@@ -837,13 +845,6 @@ def browse_snapshot_directory(
         visit_type=visit_type,
     )
 
-    vault_cooking = {
-        "directory_context": True,
-        "directory_id": sha1_git,
-        "revision_context": True,
-        "revision_id": revision_id,
-    }
-
     swhids_info = get_swhids_info(swh_objects, snapshot_context, dir_metadata)
 
     dir_path = "/".join([bc["name"] for bc in breadcrumbs]) + "/"
@@ -857,7 +858,7 @@ def browse_snapshot_directory(
     )
 
     top_right_link = None
-    if not snapshot_context["is_empty"]:
+    if not snapshot_context["is_empty"] and revision_found:
         top_right_link = {
             "url": history_url,
             "icon": swh_object_icons["revisions history"],
@@ -1009,7 +1010,7 @@ def browse_snapshot_content(
         content_url=browse_content_link,
         mimetype=content_data.get("mimetype"),
         encoding=content_data.get("encoding"),
-        size=filesizeformat(content_data.get("length", 0)),
+        size=content_data.get("length", 0),
         language=content_data.get("language"),
         root_directory=root_directory,
         path=f"/{filepath}",
