@@ -9,7 +9,6 @@ import sentry_sdk
 
 from django.http import HttpResponse
 from django.shortcuts import redirect, render
-from django.template.defaultfilters import filesizeformat
 
 from swh.model.identifiers import DIRECTORY, RELEASE, REVISION, SNAPSHOT
 from swh.web.browse.browseurls import browse_route
@@ -130,14 +129,11 @@ def _directory_browse(request, sha1_git, path=None):
         )
         if f["length"] is not None:
             sum_file_sizes += f["length"]
-            f["length"] = filesizeformat(f["length"])
         if f["name"].lower().startswith("readme"):
             readmes[f["name"]] = f["checksums"]["sha1"]
 
     readme_name, readme_url, readme_html = get_readme_to_display(readmes)
 
-    sum_file_sizes = filesizeformat(sum_file_sizes)
-
     dir_metadata = DirectoryMetadata(
         object_type=DIRECTORY,
         object_id=sha1_git,
@@ -155,9 +151,9 @@ def _directory_browse(request, sha1_git, path=None):
 
     vault_cooking = {
         "directory_context": True,
-        "directory_id": sha1_git,
+        "directory_swhid": f"swh:1:dir:{sha1_git}",
         "revision_context": False,
-        "revision_id": None,
+        "revision_swhid": None,
     }
 
     swh_objects = [SWHObjectInfo(object_type=DIRECTORY, object_id=sha1_git)]
