@@ -9,7 +9,6 @@ import textwrap
 
 from django.http import JsonResponse
 from django.shortcuts import render
-from django.template.defaultfilters import filesizeformat
 from django.utils.safestring import mark_safe
 
 from swh.model.hashutil import hash_to_bytes
@@ -444,9 +443,9 @@ def revision_browse(request, sha1_git):
 
     vault_cooking = {
         "directory_context": False,
-        "directory_id": None,
+        "directory_swhid": None,
         "revision_context": True,
-        "revision_id": sha1_git,
+        "revision_swhid": f"swh:1:rev:{sha1_git}",
     }
 
     swh_objects = [SWHObjectInfo(object_type=REVISION, object_id=sha1_git)]
@@ -515,8 +514,6 @@ def revision_browse(request, sha1_git):
                 url_args={"sha1_git": sha1_git},
                 query_params=query_params,
             )
-            if f["length"] is not None:
-                f["length"] = filesizeformat(f["length"])
             if f["name"].lower().startswith("readme"):
                 readmes[f["name"]] = f["checksums"]["sha1"]
 
@@ -529,7 +526,7 @@ def revision_browse(request, sha1_git):
         }
 
         vault_cooking["directory_context"] = True
-        vault_cooking["directory_id"] = dir_id
+        vault_cooking["directory_swhid"] = f"swh:1:dir:{dir_id}"
 
         swh_objects.append(SWHObjectInfo(object_type=DIRECTORY, object_id=dir_id))
 
