@@ -25,7 +25,7 @@ from django.urls import reverse as django_reverse
 
 from swh.web.common.exc import BadInputExc
 from swh.web.common.typing import QueryParameters
-from swh.web.config import ORIGIN_VISIT_TYPES, get_config
+from swh.web.config import get_config, search
 
 SWH_WEB_METRICS_REGISTRY = CollectorRegistry(auto_describe=True)
 
@@ -34,14 +34,20 @@ swh_object_icons = {
     "branch": "mdi mdi-source-branch",
     "branches": "mdi mdi-source-branch",
     "content": "mdi mdi-file-document",
+    "cnt": "mdi mdi-file-document",
     "directory": "mdi mdi-folder",
+    "dir": "mdi mdi-folder",
     "origin": "mdi mdi-source-repository",
+    "ori": "mdi mdi-source-repository",
     "person": "mdi mdi-account",
     "revisions history": "mdi mdi-history",
     "release": "mdi mdi-tag",
+    "rel": "mdi mdi-tag",
     "releases": "mdi mdi-tag",
     "revision": "mdi mdi-rotate-90 mdi-source-commit",
+    "rev": "mdi mdi-rotate-90 mdi-source-commit",
     "snapshot": "mdi mdi-camera",
+    "snp": "mdi mdi-camera",
     "visits": "mdi mdi-calendar-month",
 }
 
@@ -278,7 +284,7 @@ def context_processor(request):
             ]
         ),
         "swh_web_version": get_distribution("swh.web").version,
-        "visit_types": ORIGIN_VISIT_TYPES,
+        "iframe_mode": False,
     }
 
 
@@ -382,3 +388,13 @@ def get_deposits_list() -> List[Dict[str, Any]]:
         cache.set("swh-deposit-list", deposits_data)
 
     return deposits_data["results"]
+
+
+def origin_visit_types() -> List[str]:
+    """Return the exhaustive list of visit types for origins
+    ingested into the archive.
+    """
+    try:
+        return sorted(search().visit_types_count().keys())
+    except Exception:
+        return []
