@@ -22,21 +22,6 @@ STAGING_SERVER_NAMES = [
     "webapp.internal.staging.swh.network",
 ]
 
-ORIGIN_VISIT_TYPES = [
-    "cran",
-    "deb",
-    "deposit",
-    "ftp",
-    "hg",
-    "git",
-    "nixguix",
-    "npm",
-    "pypi",
-    "svn",
-    "tar",
-]
-
-
 SETTINGS_DIR = os.path.dirname(settings.__file__)
 
 DEFAULT_CONFIG = {
@@ -59,7 +44,10 @@ DEFAULT_CONFIG = {
     ),
     "search_config": (
         "dict",
-        {"backend": "swh-indexer-storage", "enable_ql": False},  # or "swh-search"
+        {
+            "metadata_backend": "swh-indexer-storage",  # or "swh-search"
+            "enable_ql": False,
+        },
     ),
     "log_dir": ("string", "/tmp/swh/log"),
     "debug": ("bool", False),
@@ -112,7 +100,6 @@ DEFAULT_CONFIG = {
             "private_api_password": "some-password",
         },
     ),
-    "coverage_count_origins": ("bool", False),
     "e2e_tests_mode": ("bool", False),
     "es_workers_index_url": ("string", ""),
     "history_counters_url": (
