@@ -4,6 +4,7 @@
 # See top-level LICENSE file for more information
 
 from datetime import datetime, timedelta
+import uuid
 
 import pytest
 
@@ -47,7 +48,7 @@ def populated_db():
     SaveUnauthorizedOrigin.objects.create(url="https://gitlab.com/user_to_exclude")
 
 
-def test_invalid_visit_type(api_client):
+def test_invalid_visit_type(api_client, swh_scheduler):
     url = reverse(
         "api-1-save-origin",
         url_args={
@@ -58,7 +59,7 @@ def test_invalid_visit_type(api_client):
     check_api_get_responses(api_client, url, status_code=400)
 
 
-def test_invalid_origin_url(api_client):
+def test_invalid_origin_url(api_client, swh_scheduler):
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": "bar"}
     )
@@ -70,59 +71,15 @@ def check_created_save_request_status(
     mocker,
     origin_url,
     expected_request_status,
-    scheduler_task_status=None,
-    scheduler_task_run_status=None,
     expected_task_status=None,
     visit_date=None,
 ):
 
-    mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
     mock_origin_exists = mocker.patch("swh.web.common.origin_save.origin_exists")
     mock_origin_exists.return_value = OriginExistenceCheckInfo(
         origin_url=origin_url, exists=True, last_modified=None, content_length=None
     )
 
-    if scheduler_task_status is None:
-        mock_scheduler.get_tasks.return_value = []
-    else:
-        mock_scheduler.get_tasks.return_value = [
-            {
-                "priority": "high",
-                "policy": "oneshot",
-                "type": "load-git",
-                "arguments": {"kwargs": {"repo_url": origin_url}, "args": []},
-                "status": scheduler_task_status,
-                "id": 1,
-            }
-        ]
-
-    if scheduler_task_run_status is None:
-        mock_scheduler.get_task_runs.return_value = []
-    else:
-        mock_scheduler.get_task_runs.return_value = [
-            {
-                "backend_id": "f00c712c-e820-41ce-a07c-9bf8df914205",
-                "ended": datetime.now(tz=timezone.utc) + timedelta(minutes=5),
-                "id": 1,
-                "metadata": {},
-                "scheduled": datetime.now(tz=timezone.utc),
-                "started": None,
-                "status": scheduler_task_run_status,
-                "task": 1,
-            }
-        ]
-
-    mock_scheduler.create_tasks.return_value = [
-        {
-            "priority": "high",
-            "policy": "oneshot",
-            "type": "load-git",
-            "arguments": {"kwargs": {"repo_url": origin_url}, "args": []},
-            "status": "next_run_not_scheduled",
-            "id": 1,
-        }
-    ]
-
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url}
     )
@@ -143,6 +100,7 @@ def check_created_save_request_status(
 def check_save_request_status(
     api_client,
     mocker,
+    swh_scheduler,
     origin_url,
     expected_request_status,
     expected_task_status,
@@ -151,33 +109,19 @@ def check_save_request_status(
     visit_date=None,
     visit_status=None,
 ):
-    mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
-    mock_scheduler.get_tasks.return_value = [
-        {
-            "priority": "high",
-            "policy": "oneshot",
-            "type": "load-git",
-            "arguments": {"kwargs": {"repo_url": origin_url}, "args": []},
-            "status": scheduler_task_status,
-            "id": 1,
-        }
-    ]
 
-    if scheduler_task_run_status is None:
-        mock_scheduler.get_task_runs.return_value = []
-    else:
-        mock_scheduler.get_task_runs.return_value = [
-            {
-                "backend_id": "f00c712c-e820-41ce-a07c-9bf8df914205",
-                "ended": datetime.now(tz=timezone.utc) + timedelta(minutes=5),
-                "id": 1,
-                "metadata": {},
-                "scheduled": datetime.now(tz=timezone.utc),
-                "started": None,
-                "status": scheduler_task_run_status,
-                "task": 1,
-            }
-        ]
+    if expected_task_status != SAVE_TASK_NOT_CREATED:
+        task = dict(swh_scheduler.search_tasks()[0].items())
+        backend_id = str(uuid.uuid4())
+
+    if scheduler_task_status != "next_run_not_scheduled":
+        swh_scheduler.schedule_task_run(task["id"], backend_id)
+
+    if scheduler_task_run_status is not None:
+        swh_scheduler.start_task_run(backend_id)
+        task_run = dict(
+            swh_scheduler.end_task_run(backend_id, scheduler_task_run_status).items()
+        )
 
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url}
@@ -194,16 +138,19 @@ def check_save_request_status(
     assert save_request_data["save_task_status"] == expected_task_status
     assert save_request_data["visit_status"] == visit_status
 
-    # Check that save task status is still available when
-    # the scheduler task has been archived
-    mock_scheduler.get_tasks.return_value = []
-    response = check_api_get_responses(api_client, url, status_code=200)
-    save_request_data = response.data[0]
-    assert save_request_data["save_task_status"] == expected_task_status
-    assert save_request_data["visit_status"] == visit_status
+    if scheduler_task_run_status is not None:
+        # Check that save task status is still available when
+        # the scheduler task has been archived
+        swh_scheduler.delete_archived_tasks(
+            [{"task_id": task["id"], "task_run_id": task_run["id"]}]
+        )
+        response = check_api_get_responses(api_client, url, status_code=200)
+        save_request_data = response.data[0]
+        assert save_request_data["save_task_status"] == expected_task_status
+        assert save_request_data["visit_status"] == visit_status
 
 
-def test_save_request_rejected(api_client, mocker):
+def test_save_request_rejected(api_client, mocker, swh_scheduler):
     origin_url = "https://github.com/user/illegal_repo"
     check_created_save_request_status(
         api_client, mocker, origin_url, expected_request_status=SAVE_REQUEST_REJECTED,
@@ -211,13 +158,14 @@ def test_save_request_rejected(api_client, mocker):
     check_save_request_status(
         api_client,
         mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_REJECTED,
         expected_task_status=SAVE_TASK_NOT_CREATED,
     )
 
 
-def test_save_request_pending(api_client, mocker):
+def test_save_request_pending(api_client, mocker, swh_scheduler):
     origin_url = "https://unkwownforge.com/user/repo"
     check_created_save_request_status(
         api_client,
@@ -229,13 +177,14 @@ def test_save_request_pending(api_client, mocker):
     check_save_request_status(
         api_client,
         mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_PENDING,
         expected_task_status=SAVE_TASK_NOT_CREATED,
     )
 
 
-def test_save_request_succeed(api_client, mocker):
+def test_save_request_scheduled(api_client, mocker, swh_scheduler):
     origin_url = "https://github.com/Kitware/CMake"
     check_created_save_request_status(
         api_client,
@@ -247,15 +196,28 @@ def test_save_request_succeed(api_client, mocker):
     check_save_request_status(
         api_client,
         mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_SCHEDULED,
         scheduler_task_status="next_run_scheduled",
         scheduler_task_run_status="scheduled",
     )
+
+
+def test_save_request_completed(api_client, mocker, swh_scheduler):
+    origin_url = "https://github.com/Kitware/CMake"
+    check_created_save_request_status(
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
+    )
     check_save_request_status(
         api_client,
         mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_SUCCEEDED,
@@ -263,10 +225,22 @@ def test_save_request_succeed(api_client, mocker):
         scheduler_task_run_status="eventful",
         visit_date=None,
     )
+
+
+def test_save_request_completed_visit_status(api_client, mocker, swh_scheduler):
+    origin_url = "https://github.com/Kitware/CMake"
+    check_created_save_request_status(
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
+    )
     visit_date = datetime.now(tz=timezone.utc) + timedelta(hours=1)
     check_save_request_status(
         api_client,
         mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_SUCCEEDED,
@@ -277,7 +251,7 @@ def test_save_request_succeed(api_client, mocker):
     )
 
 
-def test_save_request_failed(api_client, mocker):
+def test_save_request_failed(api_client, mocker, swh_scheduler):
     origin_url = "https://gitlab.com/inkscape/inkscape"
     check_created_save_request_status(
         api_client,
@@ -289,15 +263,7 @@ def test_save_request_failed(api_client, mocker):
     check_save_request_status(
         api_client,
         mocker,
-        origin_url,
-        expected_request_status=SAVE_REQUEST_ACCEPTED,
-        expected_task_status=SAVE_TASK_SCHEDULED,
-        scheduler_task_status="next_run_scheduled",
-        scheduler_task_run_status="scheduled",
-    )
-    check_save_request_status(
-        api_client,
-        mocker,
+        swh_scheduler,
         origin_url,
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_FAILED,
@@ -307,20 +273,13 @@ def test_save_request_failed(api_client, mocker):
     )
 
 
-def test_create_save_request_only_when_needed(api_client, mocker):
+def test_create_save_request_no_duplicate(api_client, mocker, swh_scheduler):
     origin_url = "https://github.com/webpack/webpack"
-    SaveOriginRequest.objects.create(
-        visit_type="git",
-        origin_url=origin_url,
-        status=SAVE_REQUEST_ACCEPTED,
-        loading_task_id=56,
-    )
 
     check_created_save_request_status(
         api_client,
         mocker,
         origin_url,
-        scheduler_task_status="next_run_not_scheduled",
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
     )
@@ -330,12 +289,21 @@ def test_create_save_request_only_when_needed(api_client, mocker):
     )
     assert len(sors) == 1
 
+    check_save_request_status(
+        api_client,
+        mocker,
+        swh_scheduler,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_ACCEPTED,
+        expected_task_status=SAVE_TASK_SCHEDULED,
+        scheduler_task_status="next_run_scheduled",
+        scheduler_task_run_status="scheduled",
+    )
+
     check_created_save_request_status(
         api_client,
         mocker,
         origin_url,
-        scheduler_task_status="next_run_scheduled",
-        scheduler_task_run_status="scheduled",
         expected_request_status=SAVE_REQUEST_ACCEPTED,
         expected_task_status=SAVE_TASK_SCHEDULED,
     )
@@ -344,37 +312,8 @@ def test_create_save_request_only_when_needed(api_client, mocker):
     )
     assert len(sors) == 1
 
-    visit_date = datetime.now(tz=timezone.utc) + timedelta(hours=1)
-    check_created_save_request_status(
-        api_client,
-        mocker,
-        origin_url,
-        scheduler_task_status="completed",
-        expected_request_status=SAVE_REQUEST_ACCEPTED,
-        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
-        visit_date=visit_date,
-    )
-    sors = list(
-        SaveOriginRequest.objects.filter(visit_type="git", origin_url=origin_url)
-    )
-    # check_api_post_responses sends two POST requests to check YAML and JSON response
-    assert len(sors) == 3
 
-    check_created_save_request_status(
-        api_client,
-        mocker,
-        origin_url,
-        scheduler_task_status="disabled",
-        expected_request_status=SAVE_REQUEST_ACCEPTED,
-        expected_task_status=SAVE_TASK_NOT_YET_SCHEDULED,
-    )
-    sors = list(
-        SaveOriginRequest.objects.filter(visit_type="git", origin_url=origin_url)
-    )
-    assert len(sors) == 5
-
-
-def test_get_save_requests_unknown_origin(api_client):
+def test_get_save_requests_unknown_origin(api_client, swh_scheduler):
     unknown_origin_url = "https://gitlab.com/foo/bar"
     url = reverse(
         "api-1-save-origin",
@@ -444,7 +383,7 @@ def origin_to_review():
 
 
 def test_create_save_request_pending_review_anonymous_user(
-    api_client, origin_to_review
+    api_client, origin_to_review, swh_scheduler
 ):
 
     url = reverse(
@@ -461,8 +400,9 @@ def test_create_save_request_pending_review_anonymous_user(
 
 
 def test_create_save_request_archives_with_ambassador_user(
-    api_client, origin_to_review, keycloak_oidc, mocker, requests_mock,
+    api_client, keycloak_oidc, requests_mock, swh_scheduler,
 ):
+    swh_scheduler.add_load_archive_task_type()
 
     keycloak_oidc.realm_permissions = [SWH_AMBASSADOR_PERMISSION]
     oidc_profile = keycloak_oidc.login()
@@ -481,32 +421,6 @@ def test_create_save_request_archives_with_ambassador_user(
         headers={"content-length": content_length, "last-modified": last_modified,},
     )
 
-    mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
-    mock_scheduler.get_task_runs.return_value = []
-    mock_scheduler.create_tasks.return_value = [
-        {
-            "id": 10,
-            "priority": "high",
-            "policy": "oneshot",
-            "status": "next_run_not_scheduled",
-            "type": "load-archive-files",
-            "arguments": {
-                "args": [],
-                "kwargs": {
-                    "url": originUrl,
-                    "artifacts": [
-                        {
-                            "url": artifact_url,
-                            "version": artifact_version,
-                            "time": last_modified,
-                            "length": content_length,
-                        }
-                    ],
-                },
-            },
-        },
-    ]
-
     url = reverse(
         "api-1-save-origin",
         url_args={"visit_type": "archives", "origin_url": originUrl,},
@@ -529,9 +443,11 @@ def test_create_save_request_archives_with_ambassador_user(
 
 
 def test_create_save_request_archives_missing_artifacts_data(
-    api_client, origin_to_review, keycloak_oidc, mocker, requests_mock,
+    api_client, keycloak_oidc, swh_scheduler
 ):
 
+    swh_scheduler.add_load_archive_task_type()
+
     keycloak_oidc.realm_permissions = [SWH_AMBASSADOR_PERMISSION]
     oidc_profile = keycloak_oidc.login()
     api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {oidc_profile['refresh_token']}")
@@ -556,7 +472,7 @@ def test_create_save_request_archives_missing_artifacts_data(
 
 
 def test_create_save_request_archives_accepted_ambassador_user(
-    api_client, origin_to_review, keycloak_oidc, mocker
+    api_client, origin_to_review, keycloak_oidc, mocker, swh_scheduler
 ):
 
     keycloak_oidc.realm_permissions = [SWH_AMBASSADOR_PERMISSION]
@@ -574,7 +490,7 @@ def test_create_save_request_archives_accepted_ambassador_user(
     assert SaveAuthorizedOrigin.objects.get(url=origin_to_review)
 
 
-def test_create_save_request_anonymous_user_no_user_id(api_client):
+def test_create_save_request_anonymous_user_no_user_id(api_client, swh_scheduler):
     origin_url = "https://some.git.hosters/user/repo"
     url = reverse(
         "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url},
@@ -588,7 +504,7 @@ def test_create_save_request_anonymous_user_no_user_id(api_client):
 
 
 def test_create_save_request_authenticated_user_id(
-    api_client, origin_to_review, keycloak_oidc, mocker
+    api_client, keycloak_oidc, swh_scheduler
 ):
     oidc_profile = keycloak_oidc.login()
     api_client.credentials(HTTP_AUTHORIZATION=f"Bearer {oidc_profile['refresh_token']}")
@@ -607,7 +523,9 @@ def test_create_save_request_authenticated_user_id(
     assert sor.user_ids == f'"{user_id}"'
 
 
-def test_create_pending_save_request_multiple_authenticated_users(api_client):
+def test_create_pending_save_request_multiple_authenticated_users(
+    api_client, swh_scheduler
+):
     origin_url = "https://some.git.hosters/user/repo3"
     first_user = User.objects.create_user(username="first_user", password="")
     second_user = User.objects.create_user(username="second_user", password="")
