@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -67,7 +67,7 @@ def test_origin_visits_browse(client, archive_data, origin):
 
 
 @given(origin_with_multiple_visits())
-def test_origin_content_view(client, archive_data, origin):
+def test_origin_content_view(client, archive_data, swh_scheduler, origin):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
     def _get_archive_data(visit_idx):
@@ -157,7 +157,7 @@ def test_origin_content_view(client, archive_data, origin):
 
 
 @given(origin())
-def test_origin_root_directory_view(client, archive_data, origin):
+def test_origin_root_directory_view(client, archive_data, swh_scheduler, origin):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
     visit = origin_visits[-1]
@@ -273,7 +273,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
 
 
 @given(origin())
-def test_origin_sub_directory_view(client, archive_data, origin):
+def test_origin_sub_directory_view(client, archive_data, swh_scheduler, origin):
     origin_visits = archive_data.origin_visit_get(origin["url"])
 
     visit = origin_visits[-1]
@@ -821,6 +821,16 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
         resp, f"Revision {unknown_revision } could not be found in the archive."
     )
 
+    # no revision card
+    assert_not_contains(resp, "swh-tip-revision")
+    # no Download dropdown
+    assert_not_contains(resp, "swh-vault-download")
+    # no History link
+    assert_not_contains(resp, "swh-tr-link")
+    # no SWHIDs for directory and revision
+    assert_not_contains(resp, "swh:1:dir:")
+    assert_not_contains(resp, "swh:1:rev:")
+
 
 @given(origin())
 def test_origin_content_no_path(client, origin):
@@ -1297,3 +1307,22 @@ def test_pull_request_branches_filtering(client, origin):
         client, url, status_code=200, template_used="browse/branches.html"
     )
     assert_not_contains(resp, "refs/pull/")
+
+
+@given(origin_with_pull_request_branches())
+def test_browse_pull_request_branch(client, archive_data, origin):
+    snapshot = archive_data.snapshot_get_latest(origin.url)
+    pr_branch = random.choice(
+        [
+            branch
+            for branch in snapshot["branches"].keys()
+            if branch.startswith("refs/pull/")
+        ]
+    )
+    url = reverse(
+        "browse-origin-directory",
+        query_params={"origin_url": origin.url, "branch": pr_branch},
+    )
+    check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
